@@ -7,19 +7,22 @@
 /**
  * @file api/v1/submissions/index.php
  *
- * Copyright (c) 2014-2021 Simon Fraser University
- * Copyright (c) 2003-2021 John Willinsky
+ * Copyright (c) 2023 Simon Fraser University
+ * Copyright (c) 2023 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup api_v1_submissions
+ *
  * @brief Handle requests for submission API functions.
  *
  */
+
+use APP\core\Application;
+
 $requestPath = Application::get()->getRequest()->getRequestPath();
+
 if (strpos($requestPath, '/files')) {
-	import('lib.pkp.api.v1.submissions.PKPSubmissionFileHandler');
-	return new PKPSubmissionFileHandler();
+    return new \PKP\handler\APIHandler(new \PKP\API\v1\submissions\PKPSubmissionFileController());
 } else {
-	import('api.v1.submissions.SubmissionHandler');
-	return new SubmissionHandler();
-}
\ No newline at end of file
+    return new \PKP\handler\APIHandler(new \APP\API\v1\submissions\SubmissionController());
+}
