@@ -15,6 +15,7 @@
 namespace APP\migration\install;
 
 use Illuminate\Database\Schema\Blueprint;
+use Illuminate\Support\Facades\DB;
 use Illuminate\Support\Facades\Schema as Schema;
 
 class MetricsMigration extends \PKP\migration\Migration
@@ -29,7 +30,7 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->comment('Daily statistics for views of the homepage.');
             $table->bigIncrements('metrics_context_id');
 
-            $table->string('load_id', 255);
+            $table->string('load_id', 50);
             $table->index(['load_id'], 'metrics_context_load_id');
 
             $table->bigInteger('context_id');
@@ -43,7 +44,7 @@ class MetricsMigration extends \PKP\migration\Migration
         Schema::create('metrics_submission', function (Blueprint $table) {
             $table->comment('Daily statistics for views and downloads of published submissions and galleys.');
             $table->bigIncrements('metrics_submission_id');
-            $table->string('load_id', 255);
+            $table->string('load_id', 50);
             $table->index(['load_id'], 'ms_load_id');
 
             $table->bigInteger('context_id');
@@ -74,7 +75,7 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->comment('Daily statistics matching the COUNTER R5 protocol for views and downloads of published submissions and galleys.');
             $table->bigIncrements('metrics_counter_submission_daily_id');
 
-            $table->string('load_id', 255);
+            $table->string('load_id', 50);
             $table->index(['load_id'], 'msd_load_id');
 
             $table->bigInteger('context_id');
@@ -120,7 +121,7 @@ class MetricsMigration extends \PKP\migration\Migration
         Schema::create('metrics_counter_submission_institution_daily', function (Blueprint $table) {
             $table->comment('Daily statistics matching the COUNTER R5 protocol for views and downloads from institutions.');
             $table->bigIncrements('metrics_counter_submission_institution_daily_id');
-            $table->string('load_id', 255);
+            $table->string('load_id', 50);
             $table->index(['load_id'], 'msid_load_id');
 
             $table->bigInteger('context_id');
@@ -175,7 +176,7 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->comment('Daily statistics by country, region and city for views and downloads of published submissions and galleys.');
             $table->bigIncrements('metrics_submission_geo_daily_id');
 
-            $table->string('load_id', 255);
+            $table->string('load_id', 50);
             $table->index(['load_id'], 'msgd_load_id');
 
             $table->bigInteger('context_id');
@@ -194,7 +195,15 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->integer('metric_unique');
 
             $table->index(['context_id', 'submission_id'], 'msgd_context_id_submission_id');
-            $table->unique(['load_id', 'context_id', 'submission_id', 'country', 'region', 'city', 'date'], 'msgd_uc_load_context_submission_c_r_c_date');
+            match (DB::getDriverName()) {
+                'mysql', 'mariadb' =>
+                    // See "Create a database table" here: https://db-ip.com/db/format/ip-to-city-lite/csv.html
+                    // where city is defined as varchar(80)
+                    $table->unique([DB::raw('load_id, context_id, submission_id, country, region, city(80), date')], 'msgd_uc_load_context_submission_c_r_c_date'),
+
+                'pgsql' =>
+                    $table->unique(['load_id', 'context_id', 'submission_id', 'country', 'region', 'city', 'date'], 'msgd_uc_load_context_submission_c_r_c_date'),
+            };
         });
 
         Schema::create('metrics_submission_geo_monthly', function (Blueprint $table) {
@@ -217,7 +226,14 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->integer('metric_unique');
 
             $table->index(['context_id', 'submission_id'], 'msgm_context_id_submission_id');
-            $table->unique(['context_id', 'submission_id', 'country', 'region', 'city', 'month'], 'msgm_uc_context_submission_c_r_c_month');
+            match (DB::getDriverName()) {
+                'mysql', 'mariadb' =>
+                    // See "Create a database table" here: https://db-ip.com/db/format/ip-to-city-lite/csv.html
+                    // where city is defined as varchar(80)
+                    $table->unique([DB::raw('context_id, submission_id, country, region, city(80), month')], 'msgm_uc_context_submission_c_r_c_month'),
+                'pgsql' =>
+                    $table->unique(['context_id', 'submission_id', 'country', 'region', 'city', 'month'], 'msgm_uc_context_submission_c_r_c_month'),
+            };
         });
 
         // Usage stats total item temporary records
@@ -226,7 +242,7 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->bigIncrements('usage_stats_temp_total_id');
 
             $table->dateTime('date', $precision = 0);
-            $table->string('ip', 255);
+            $table->string('ip', 64);
             $table->string('user_agent', 255);
             $table->bigInteger('line_number');
             $table->string('canonical_url', 255);
@@ -252,7 +268,9 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->string('country', 2)->default('');
             $table->string('region', 3)->default('');
             $table->string('city', 255)->default('');
-            $table->string('load_id', 255);
+            $table->string('load_id', 50);
+
+            $table->index(['load_id', 'context_id', 'ip', 'user_agent', 'canonical_url'], 'ust_load_id_context_id_ip_ua_url');
         });
 
         // Usage stats unique item investigations temporary records
@@ -261,7 +279,7 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->bigIncrements('usage_stats_temp_unique_item_id');
 
             $table->dateTime('date', $precision = 0);
-            $table->string('ip', 255);
+            $table->string('ip', 64);
             $table->string('user_agent', 255);
             $table->bigInteger('line_number');
 
@@ -286,7 +304,9 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->string('country', 2)->default('');
             $table->string('region', 3)->default('');
             $table->string('city', 255)->default('');
-            $table->string('load_id', 255);
+            $table->string('load_id', 50);
+
+            $table->index(['load_id', 'context_id', 'ip', 'user_agent'], 'usii_load_id_context_id_ip_ua');
         });
 
         // Usage stats unique item requests temporary records
@@ -294,7 +314,7 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->comment('Temporary stats on unique views based on visitor log records. Data in this table is provisional. See the metrics_* tables for compiled stats.');
             $table->bigIncrements('usage_stats_temp_item_id');
             $table->dateTime('date', $precision = 0);
-            $table->string('ip', 255);
+            $table->string('ip', 64);
             $table->string('user_agent', 255);
             $table->bigInteger('line_number');
 
@@ -319,7 +339,9 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->string('country', 2)->default('');
             $table->string('region', 3)->default('');
             $table->string('city', 255)->default('');
-            $table->string('load_id', 255);
+            $table->string('load_id', 50);
+
+            $table->index(['load_id', 'context_id', 'ip', 'user_agent'], 'usir_load_id_context_id_ip_ua');
         });
 
         // Usage stats institution temporary records
@@ -328,7 +350,7 @@ class MetricsMigration extends \PKP\migration\Migration
             $table->comment('Temporary stats for views and downloads from institutions based on visitor log records. Data in this table is provisional. See the metrics_* tables for compiled stats.');
             $table->bigIncrements('usage_stats_temp_institution_id');
 
-            $table->string('load_id', 255);
+            $table->string('load_id', 50);
             $table->bigInteger('line_number');
 
             $table->bigInteger('institution_id');
