@@ -29,7 +29,7 @@ class AssignDOIsOnSubmission
     {
         $events->listen(
             SubmissionSubmitted::class,
-            self::class . '@handle'
+            AssignDOIsOnSubmission::class
         );
     }
 
