@@ -12,25 +12,18 @@
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup pages_preprints
+ *
  * @brief Handle requests for preprints archive view.
  *
  */
 
 switch ($op) {
-	case 'index':
-		define('HANDLER_CLASS', 'PreprintsHandler');
-		import('pages.preprints.PreprintsHandler');
-		break;
-	case 'category':
-	case 'fullSize':
-	case 'thumbnail':
-		define('HANDLER_CLASS', 'PKPCatalogHandler');
-		import('lib.pkp.pages.catalog.PKPCatalogHandler');
-		break;
-	case 'section':
-		define('HANDLER_CLASS', 'SectionsHandler');
-		import('pages.preprints.SectionsHandler');
-		break;
+    case 'index':
+        return new APP\pages\preprints\PreprintsHandler();
+    case 'category':
+    case 'fullSize':
+    case 'thumbnail':
+        return new PKP\pages\catalog\PKPCatalogHandler();
+    case 'section':
+        return new APP\pages\preprints\SectionsHandler();
 }
-
-
